@@ -108,8 +108,14 @@ sub run {
         Cwd::realpath(File::Spec->join(File::Basename::dirname(__FILE__),'p6tokens.pl')));
 
     my ($out, $err) = ('',undef);
-    run3 \@cmd, \$text, \$out, \$err;
+    run3(\@cmd, \$text, \$out, \$err, { 
+          'binmode_stdin' => ':utf8', 
+          'binmode_stdout' => 1, 
+    });
     if($err) {
+        # remove ANSI color escape sequences...
+        $err =~ s/\033\[\d+(?:;\d+(?:;\d+)?)?m//g;
+        say qq{STD.pm warning/error:\n$err};
         my @messages = split /\n/, $err;
         my ($lineno,$severity);
         my $issues = [];
